# Sidra helpers (PT-BR)

Sidra_helpers é uma pequena biblioteca Python que criei para me auxiliar na criação de gráficos no Excel. Os gráficos são, em sua maioria, de dados tirados do SIDRA, do IBGE (daí o nome).

# Sidra helpers (EN)

Sidra_helpers is a small Python library I made for my personal use. Its purpose is to facilitate the creation of excel charts with data series mainly from SIDRA ("Sistema de Recuperação automática", from the Brazilian IBGE).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install sidra_helpers.

```bash
pip install sidra_helpers
```

## Usage

```python
import sidra_helpers
```

## License

[MIT](https://choosealicense.com/licenses/mit/)
